<template>
  <a-card
    :bordered="false"
    class="card-area"
  >
    <template slot="title">
      <i
        class="action-jeecg actionsite2"
        style="font-size: 18px;"
      />
      备件信息
    </template>
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <!-- 搜索区域 -->
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :md="8"
            :sm="8"
          >
            <a-form-item label="备件编号">
              <j-input
                placeholder="请输入备件编号查询"
                v-model="queryParam.num"
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="8"
            :sm="8"
          >
            <a-form-item label="备件名称">
              <j-input
                placeholder="请输入备件名称查询"
                v-model="queryParam.name"
              ></j-input>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div
      class="table-operator"
      style="margin-top: 5px"
    >
      <a-button
        type="primary"
        @click="searchQuery"
        icon="search"
      >查询</a-button>
      <a-button
        @click="searchReset"
        icon="reload"
      >重置</a-button>
      <a-button
        @click="handleAdd"
        type="primary"
        v-has="'sparePartList:add'"
        icon="plus"
        :hidden="disabled"
      >新增</a-button>
      <a-button
        type="primary"
        icon="download"
        @click="handleExportXls('???')"
      >导出</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-button style="margin-left: 8px">
          批量操作
          <a-icon type="down" />
        </a-button>
        <a-menu slot="overlay" >
          <a-menu-item @click="batchDel" v-has="'sparePartList:delete'">
            <a-icon type="delete" />删除
          </a-menu-item>
        </a-menu>
      </a-dropdown>
    </div>

    <a-table
      ref="table"
      bordered
      size="middle"
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      :loading="loading"
      :rowSelection="rowSelection"
      @change="handleTableChange"
      :scroll="{ x: 'calc(1500px + 50%)', y: 900 }"
      :customRow="clickThenSelect"
    >

      <span
        slot="action"
        slot-scope="text, record"
      >
        <a
          href="javascript:;"
          v-has="'sparePartList:edit'"
          @click="handleEdit(record)"
        >编辑</a>
        <a-divider type="vertical" />
        <a-dropdown>
          <a class="ant-dropdown-link">
            更多
            <a-icon type="down" />
          </a>
          <a-menu slot="overlay">
            <!-- <a-menu-item>
              <a @click="handleEdit(record)">编辑</a>
            </a-menu-item> -->
            <a-menu-item>
              <a-popconfirm
                title="确定删除吗?"
                @confirm="() => handleDelete(record.id)"
              >
                <a>删除</a>
              </a-popconfirm>
            </a-menu-item>
          </a-menu>
        </a-dropdown>
      </span>
    </a-table>

    <a-tabs
      type="card"
      defaultActiveKey="1"
    >
      <a-tab-pane key="1">
        <span slot="tab">
          <a-badge>适配设备&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a-badge>
        </span>
        <div
          class="table-operator"
          style="margin-top: 0px"
        >
          <equipment-list ref="EquipmentList"></equipment-list>
        </div>
      </a-tab-pane>

    </a-tabs>
    <spare-part-model
      ref="modalForm"
      @ok="modalFormOk"
    ></spare-part-model>

  </a-card>
</template>

<script>
import { requestPut, deleteAction, getFileAccessHttpUrl, getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import SparePartModel from './SparePartModel.vue'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import Tooltip from 'ant-design-vue/es/tooltip'
import Vue from 'vue'
import EquipmentList from './EquipmentList'

export default {
  name: 'SparePart2List.',
  mixins: [JeecgListMixin],
  components: {
    SparePartModel,
    JInput,
    JEllipsis,
    EquipmentList,
    Tooltip
  },
  props: {
    nodeSelected: {
      type: Object,
      default: {}
    }
  },
  data() {
    return {
      disabled: true,
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '20'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      selectedRowKeys: [],
      selectionRows: [],
      //默认排序
      isorter: {
        column: 'num',
        order: 'asc',
      },

      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '备件编码',
          align: "center",
          dataIndex: 'num',
        },
        {
          title: '备件名称',
          align: "center",
          dataIndex: 'name',
        },
        {
          title: '型号',
          align: "center",
          dataIndex: 'model',
        },
        {
          title: '规格',
          align: "center",
          dataIndex: 'specification',
        },
        {
          title: '制造商',
          align: "center",
          dataIndex: 'constructorId_dictText',
        },
        {
          title: '单位',
          align: "center",
          dataIndex: 'mainUnitId_dictText',
        },
       /*  {
          title: '辅单位',
          align: "center",
          dataIndex: 'auxiliaryUnitId_dictText',
        }, */
        // {
        //   title: '主数量',
        //   align: "center",
        //   dataIndex: 'mainQuantity',
        // },
        // {
        //   title: '辅数量',
        //   align: "center",
        //   dataIndex: 'auxiliaryQuantity',
        // },
        {
          title: '有效期',
          align: "center",
          dataIndex: 'validityPeriod',
        },
        {
          title: '有效单位',
          align: "center",
          dataIndex: 'validityPeriodUnitId_dictText',
        },
        {
          title: '库存上限值',
          align: "center",
          dataIndex: 'inventoryUpperLimit',
        },
        {
          title: '库存下限值',
          align: "center",
          dataIndex: 'inventoryLowerLimit',
        },
        {
          title: '经济订货量',
          align: "center",
          dataIndex: 'economicOrderQuantity',
        },
        {
          title: '采购提前期',
          align: "center",
          dataIndex: 'purchaseLeadTime',
        },
        {
          title: '操作',
          align: "center",
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action',
          },
          width: 200,
          fixed: 'right',
        },
      ],
      url: {
        list: "/spare/sparePart/list",
        delete: "/spare/sparePart/delete",
        deleteBatch: "/spare/sparePart/deleteBatch",
        exportXlsUrl: '/spare/sparePart/exportXls',
        // importExcelUrl: 'base/site/importExcel',
      },
      //新增、编辑、删除、批量删除操作改变数据后刷新关联的组件的监听属性
      alterFlag: "",
      equipmentRecord: {},
      // parentNum: "-1",
      // parentName: "设备分类",
    };
  },

  computed: {
    rowSelection() {
      return {
        type: 'checkbox',
        onChange: (selectedRowKeys, selectedRows) => {
          this.selectedRowKeys = selectedRowKeys;
          this.onSelectChange(selectedRowKeys, selectedRows);
        },
        getCheckboxProps(record) {
          return ({
            props: {
              // disabled: !(record.equipmentCategoryDtlList.length == 0),
            }
          })
        },
        selectedRowKeys: this.selectedRowKeys,
      };
    },
  },
  methods: {

    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(","), [record]);
          }
        }
      }
    },

    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {
        this.$refs.EquipmentList.sparePartId = selectedRowKeys[0]
      } else {
        this.$refs.EquipmentList.sparePartId = '-1'
      }
      this.selectedRowKeys = selectedRowKeys;
      this.selectionRows = selectionRows;
    },

    //禁用状态样式
    tableRowClass(record, index) {
      if (record.status != "1") {
        return "frozenRowClass";
      }
      return "";
    },
    handleAdd: function () {
      this.$refs.modalForm.add();
      this.$refs.modalForm.title = "新增";
      this.$refs.modalForm.disableSubmit = false;
      this.$refs.modalForm.sparePartCategoryId = this.nodeSelected.key;
    },
    handleDelete: function (id) {
      if (!this.url.delete) {
        this.$message.error("请设置url.delete属性!")
        return
      }
      var that = this;
      deleteAction(that.url.delete, { id: id }).then((res) => {
        if (res.success) {
          //重新计算分页问题
          that.reCalculatePage(1)
          that.$message.success(res.message);
          that.loadData();
          that.alterFlag = new Date();
        } else {
          that.$message.warning(res.message);
        }
      });
    },

    batchDel: function () {
      if (!this.url.deleteBatch) {
        this.$message.error("请设置url.deleteBatch属性!")
        return
      }
      if (this.selectedRowKeys.length <= 0) {
        this.$message.warning('请选择一条记录！');
        return;
      } else {
        var ids = "";
        for (var a = 0; a < this.selectedRowKeys.length; a++) {
          ids += this.selectedRowKeys[a] + ",";
        }
        var that = this;
        this.$confirm({
          title: "确认删除",
          content: "是否删除选中数据?",
          onOk: function () {
            that.loading = true;
            deleteAction(that.url.deleteBatch, { ids: ids }).then((res) => {
              if (res.success) {
                //重新计算分页问题
                that.reCalculatePage(that.selectedRowKeys.length)
                that.$message.success(res.message);
                that.loadData();
                that.onClearSelected();
                that.alterFlag = new Date();
              } else {
                that.$message.warning(res.message);
              }
            }).finally(() => {
              that.loading = false;
            });
          }
        });
      }
    },

    searchReset() {
      this.queryParam = {};
      if (this.nodeSelected.key != -1) {
        this.disabled = false;
        this.queryParam.sparePartCategoryId = this.nodeSelected.key;
      } else {
        this.disabled = true;
      }
      this.selectedRowKeys = []
      this.selectionRows = []
      this.$refs.EquipmentList.sparePartId = '-1'
      this.loadData(1);
    },

    searchQuery() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.$refs.EquipmentList.sparePartId = '-1'
      this.loadData(1);
    },

    modalFormOk() {
      // 新增/修改 成功时，重载列表
      this.loadData()
      //清空列表选中
      this.onClearSelected()
      this.$refs.EquipmentList.sparePartId = '-1'
    },
  },
  watch: {
    alterFlag() {
      this.$bus.$emit('queryTreeData');
    },
    nodeSelected() {
      this.queryParam = {};
      if (this.nodeSelected.key != -1) {
        this.disabled = false;
        this.queryParam.sparePartCategoryId = this.nodeSelected.key;
      } else {
        this.disabled = true;
      }
      this.selectedRowKeys = []
      this.selectionRows = []
      this.$refs.EquipmentList.sparePartId = '-1'
      this.loadData(1);
    },
  },
  created() {
    this.queryParam = {};
    this.queryParam.sparePartCategoryId = this.nodeSelected.key;
    this.selectedRowKeys = []
    this.selectionRows = []
    this.loadData(1);
  }


}
</script>
<style>
@import '~@assets/less/common.less';

.frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
</style>